@@ -13,7 +13,7 @@
 * @author    Benedikt Hallinger <beni@php.net>
 * @copyright 2003-2007 Tarjej Huse, Jan Wagner, Del Elson, Benedikt Hallinger
 * @license   http://www.gnu.org/copyleft/lesser.html LGPL
-* @version   CVS: $Id: LDAP.php,v 1.89 2008/03/19 08:10:54 beni Exp $
+* @version   CVS: $Id: LDAP.php,v 1.95 2009/07/03 09:32:25 beni Exp $
 * @link      http://pear.php.net/package/Net_LDAP/
 */
 
@@ -37,7 +37,7 @@ define('NET_LDAP_ERROR', 1000);
 /**
 * Net_LDAP Version
 */
-define('NET_LDAP_VERSION', '1.1.1');
+define('NET_LDAP_VERSION', '1.1.5');
 
 /**
 * Net_LDAP - manipulate LDAP servers the right way!
@@ -50,7 +50,6 @@ define('NET_LDAP_VERSION', '1.1.1');
 * @author    Benedikt Hallinger <beni@php.net>
 * @copyright 2003-2007 Tarjej Huse, Jan Wagner, Del Elson, Benedikt Hallinger
 * @license   http://www.gnu.org/copyleft/lesser.html LGPL
-* @version   CVS: $Id: LDAP.php,v 1.89 2008/03/19 08:10:54 beni Exp $
 * @link      http://pear.php.net/package/Net_LDAP/
 */
 class Net_LDAP extends PEAR
@@ -58,7 +57,8 @@ class Net_LDAP extends PEAR
     /**
     * Class configuration array
     *
-    * host     = the ldap host to connect to (may be an array of several hosts to try)
+    * host     = the ldap host to connect to (may be an array of several hosts
+    *            to try)
     * port     = the server port
     * version  = ldap version (defaults to v 3)
     * starttls = when set, ldap_start_tls() is run after connecting.
@@ -239,7 +239,8 @@ class Net_LDAP extends PEAR
             if (strlen($this->_config['host']) > 0) {
                 $this->_host_list = array($this->_config['host']);
             } else {
-                $this->_host_list = array(); // this will cause an error in _connect(), so the user is notified
+                // this will cause an error in _connect(), so the user is notified
+                $this->_host_list = array();
             }
         }
 
@@ -348,13 +349,13 @@ class Net_LDAP extends PEAR
         //
         // Default error message in case all connection attempts fail but no message is set
         //
-        $current_error =& new PEAR_Error('Unknown connection error');
+        $current_error = new PEAR_Error('Unknown connection error');
 
         //
         // Catch empty $_host_list arrays.
         //
         if (!is_array($this->_host_list) || count($this->_host_list) == 0) {
-            $current_error = PEAR::raiseError('No Servers configured! Please pass in an array of servers to Net_LDAP');
+            $current_error = PEAR::raiseError('No Servers configured! Please pass in an array of servers to Net_LDAP2');
             return $current_error;
         }
 
@@ -367,7 +368,7 @@ class Net_LDAP extends PEAR
             // Ensure we have a valid string for host name
             //
             if (is_array($host)) {
-                $current_error = PEAR::raiseError('No Servers configured! Please pass in an one dimensional array of servers to Net_LDAP! (multidimensional array detected!)');
+                $current_error = PEAR::raiseError('No Servers configured! Please pass in an one dimensional array of servers to Net_LDAP2! (multidimensional array detected!)');
                 continue;
             }
 
@@ -391,25 +392,28 @@ class Net_LDAP extends PEAR
             if (false === $this->_link) {
                 $current_error = PEAR::raiseError('Could not connect to ' .
                     $host . ':' . $this->_config['port']);
-                continue;
-            }
-
-            //
-            // Set LDAP version before trying to bind.
-            //
-            if (Net_LDAP::isError($msg = $this->setLDAPVersion())) {
-                $current_error           = $msg;
-                $this->_link             = false;
                 $this->_down_host_list[] = $host;
                 continue;
             }
 
+            //
+            // If we're supposed to use TLS, do so before we try to bind.
+            //
+            if ($this->_config["starttls"] === true) {
+                if (self::isError($msg = $this->startTLS())) {
+                    $current_error           = $msg;
+                    $this->_link             = false;
+                    $this->_down_host_list[] = $host;
+                    continue;
+                }
+            }
+
             //
             // Attempt to bind to the server. If we have credentials configured,
-            // we try to use them, otherwiese its an anonymous bind.
+            // we try to use them, otherwise its an anonymous bind.
             //
             $msg = $this->bind();
-            if (Net_LDAP::isError($msg)) {
+            if (self::isError($msg)) {
                 // The bind failed, discard link and save error msg.
                 // Then record the host as down and try next one
                 $this->_link             = false;
@@ -418,23 +422,25 @@ class Net_LDAP extends PEAR
                 continue;
             }
 
+            //
+            // Set LDAP version after we have a bind.
+            //
+            if (self::isError($msg = $this->setLDAPVersion())) {
+                $current_error           = $msg;
+                $this->_link             = false;
+                $this->_down_host_list[] = $host;
+                continue;
+            }
+
             //
             // Set LDAP parameters, now we know we have a valid connection.
             //
-            if ($this->_config["starttls"] === true) {
-                if (Net_LDAP::isError($msg = $this->startTLS())) {
-                    $current_error           = $msg;
-                    $this->_link             = false;
-                    $this->_down_host_list[] = $host;
-                    continue;
-                }
-            }
             if (isset($this->_config['options']) &&
                 is_array($this->_config['options']) &&
                 count($this->_config['options'])) {
                 foreach ($this->_config['options'] as $opt => $val) {
                     $err = $this->setOption($opt, $val);
-                    if (Net_LDAP::isError($err)) {
+                    if (self::isError($err)) {
                         $current_error           = $err;
                         $this->_link             = false;
                         $this->_down_host_list[] = $host;
@@ -700,21 +706,25 @@ class Net_LDAP extends PEAR
         if (is_null($base)) {
             $base = $this->_config['basedn'];
         }
+
         if (is_null($filter)) {
             $filter = $this->_config['filter'];
         }
+
         if (is_a($filter, 'Net_LDAP_Filter')) {
             $filter = $filter->asString(); // convert Net_LDAP_Filter to string representation
         }
+
         if (PEAR::isError($filter)) {
             return $filter;
         }
 
         /* setting searchparameters  */
-        (isset($params['sizelimit']))  ? $sizelimit  = $params['sizelimit']  : $sizelimit = 0;
-        (isset($params['timelimit']))  ? $timelimit  = $params['timelimit']  : $timelimit = 0;
-        (isset($params['attrsonly']))  ? $attrsonly  = $params['attrsonly']  : $attrsonly = 0;
-        (isset($params['attributes'])) ? $attributes = $params['attributes'] : $attributes = array();
+        $sizelimit = isset($params['sizelimit'])  ? $params['sizelimit'] : 0;
+        $timelimit = isset($params['timelimit'])  ? $params['timelimit'] : 0;
+        $attrsonly = isset($params['attrsonly'])  ? $params['attrsonly'] : 0;
+
+        $attributes = isset($params['attributes'])? $params['attributes'] : array();
 
         // Ensure $attributes to be an array in case only one
         // attribute name was given as string
@@ -1253,7 +1263,9 @@ class Net_LDAP extends PEAR
     function checkLDAPExtension()
     {
         if (!extension_loaded('ldap') && !@dl('ldap.' . PHP_SHLIB_SUFFIX)) {
-            return PEAR::raiseError("It seems that you do not have the ldap-extension installed. Please install it before using the Net_LDAP package.");
+            $msg  = "It seems that you do not have the ldap-extension installed.";
+            $msg .= "Please install it before using the Net_LDAP package.";
+            return PEAR::raiseError($msg);
         } else {
             return true;
         }
@@ -1262,13 +1274,15 @@ class Net_LDAP extends PEAR
     /**
     * Encodes given attributes to UTF8 if needed by schema
     *
-    * This function takes attributes in an array and then checks against the schema if they need
-    * UTF8 encoding. If that is so, they will be encoded. An encoded array will be returned and
-    * can be used for adding or modifying.
+    * This function takes attributes in an array and then checks against the schema
+    * if they need UTF8 encoding. If that is so, they will be encoded. An encoded 
+    * array will be returned and can be used for adding or modifying.
     *
     * $attributes is expected to be an array with keys describing
     * the attribute names and the values as the value of this attribute:
-    * <code>$attributes = array('cn' => 'foo', 'attr2' => array('mv1', 'mv2'));</code>
+    * <code>
+    * $attributes = array('cn' => 'foo', 'attr2' => array('mv1', 'mv2'));
+    * </code>
     *
     * @param array $attributes Array of attributes
     *
@@ -1285,7 +1299,9 @@ class Net_LDAP extends PEAR
     *
     * $attributes is expected to be an array with keys describing
     * the attribute names and the values as the value of this attribute:
-    * <code>$attributes = array('cn' => 'foo', 'attr2' => array('mv1', 'mv2'));</code>
+    * <code>
+    * $attributes = array('cn' => 'foo', 'attr2' => array('mv1', 'mv2'));
+    * </code>
     *
     * @param array $attributes Array of attributes
     *
@@ -1305,19 +1321,22 @@ class Net_LDAP extends PEAR
     * @param array $function   Function to apply to attribute values
     *
     * @access private
-    * @return array|Net_LDAP_Error Array of attributes with function applied to values or Error
+    * @return array|Net_LDAP_Error Array of attributes with function
+    *         applied to values or Error
     */
     function _utf8($attributes, $function)
     {
         if (!is_array($attributes) || array_key_exists(0, $attributes)) {
-            return PEAR::raiseError('Parameter $attributes is expected to be an associative array');
+            $msg = 'Parameter $attributes is expected to be an associative array';
+            return PEAR::raiseError($msg);
         }
 
         if (!$this->_schema) {
             $this->_schema = $this->schema();
         }
 
-        if (!$this->_link || Net_LDAP::isError($this->_schema) || !function_exists($function)) {
+        if (!$this->_link || Net_LDAP::isError($this->_schema) 
+            || !function_exists($function)) {
             return $attributes;
         }
 
@@ -1332,7 +1351,8 @@ class Net_LDAP extends PEAR
                         continue;
                     }
 
-                    if (false !== strpos($attr['syntax'], '1.3.6.1.4.1.1466.115.121.1.15')) {
+                    $haystack = '1.3.6.1.4.1.1466.115.121.1.15';
+                    if (false !== strpos($attr['syntax'], $haystack)) {
                         $encode = true;
                     } else {
                         $encode = false;
@@ -1387,21 +1407,29 @@ class Net_LDAP_Error extends PEAR_Error
      * @param string  $message   String with error message.
      * @param integer $code      Net_LDAP error code
      * @param integer $mode      what "error mode" to operate in
-     * @param mixed   $level     what error level to use for $mode & PEAR_ERROR_TRIGGER
+     * @param mixed   $level     what error level to use for $mode & 
+     *                           PEAR_ERROR_TRIGGER
      * @param mixed   $debuginfo additional debug info, such as the last query
      *
      * @access public
      * @see PEAR_Error
      */
-    function Net_LDAP_Error($message = 'Net_LDAP_Error', $code = NET_LDAP_ERROR, $mode = PEAR_ERROR_RETURN,
-                            $level = E_USER_NOTICE, $debuginfo = null)
+    function Net_LDAP_Error($message = 'Net_LDAP_Error', $code = NET_LDAP_ERROR,
+                            $mode = PEAR_ERROR_RETURN, $level = E_USER_NOTICE,
+                            $debuginfo = null)
     {
+        $error_code = NET_LDAP_ERROR;
+
+        $msg = "$message: $code";
+
         if (is_int($code)) {
-            $this->PEAR_Error($message . ': ' . Net_LDAP::errorMessage($code), $code, $mode, $level, $debuginfo);
-        } else {
-            $this->PEAR_Error("$message: $code", NET_LDAP_ERROR, $mode, $level, $debuginfo);
+            $msg = $message . ': ' . Net_LDAP::errorMessage($code);
+
+            $error_code = $code;
         }
+
+        $this->PEAR_Error($msg, $error_code, $mode, $level, $debuginfo);
     }
 }
 
-?>
\ No newline at end of file
+?>
