@@ -1,5 +1,19 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4: */
+/**
+* Entry.php
+*
+* PHP version 4, 5
+*
+* @category  Net
+* @package   Net_LDAP
+* @author    Tarjej Huse <tarjei@bergfald.no>
+* @author    Jan Wagner <wagner@netsols.de>
+* @copyright 2003-2007 Tarjej Huse, Jan Wagner, Del Elson, Benedikt Hallinger
+* @license   http://www.gnu.org/copyleft/lesser.html LGPL
+* @version   CVS: $Id: Entry.php,v 1.58 2008/11/03 14:06:27 beni Exp $
+* @link      http://pear.php.net/package/Net_LDAP/
+*/
 
 require_once 'PEAR.php';
 require_once 'Util.php';
@@ -15,9 +29,7 @@ require_once 'Util.php';
 * @author   Jan Wagner <wagner@netsols.de>
 * @author   Tarjej Huse <tarjei@bergfald.no>
 * @license  http://www.gnu.org/copyleft/lesser.html LGPL
-* @version  CVS: $Id: Entry.php,v 1.54 2008/02/27 08:59:42 beni Exp $
 * @link     http://pear.php.net/package/Net_LDAP/
-
 */
 class Net_LDAP_Entry extends PEAR
 {
@@ -437,18 +449,19 @@ class Net_LDAP_Entry extends PEAR
                     $v = array($v);
                 }
             }
-            // add new values to existing attribute
+            // add new values to existing attribute or add new attribute
             if ($this->exists($k)) {
-                $this->_attributes[$k] = array_merge($this->_attributes[$k], $v);
+                $this->_attributes[$k] = array_unique(array_merge($this->_attributes[$k], $v));
             } else {
                 $this->_map[strtolower($k)] = $k;
                 $this->_attributes[$k]      = $v;
             }
+
             // save changes for update()
             if (empty($this->_changes["add"][$k])) {
                 $this->_changes["add"][$k] = array();
             }
-            $this->_changes["add"][$k] = array_merge($this->_changes["add"][$k], $v);
+            $this->_changes["add"][$k] = array_unique(array_merge($this->_changes["add"][$k], $v));
         }
         $return = true;
         return $return;
@@ -522,7 +535,7 @@ class Net_LDAP_Entry extends PEAR
                             $this->_changes["delete"][$name] = array();
                         }
                         $this->_changes["delete"][$name] =
-                            array_merge($this->_changes["delete"][$name], $values);
+                             array_unique(array_merge($this->_changes["delete"][$name], $values));
                         foreach ($values as $value) {
                             // find the key for the value that should be deleted
                             $key = array_search($value, $this->_attributes[$name]);
@@ -609,7 +622,11 @@ class Net_LDAP_Entry extends PEAR
             return PEAR::raiseError("The entries LDAP object is not valid");
         }
 
+        // Get and check link
         $link = $ldap->getLink();
+        if (!is_resource($link)) {
+            return PEAR::raiseError("Could not update entry: internal LDAP link is invalid");
+        }
 
         /*
         * Delete the entry
@@ -895,4 +912,4 @@ class Net_LDAP_Entry extends PEAR
         return $this->_changes;
     }
 }
-?>
\ No newline at end of file
+?>
