@@ -38,7 +38,7 @@ require_once 'Util.php';
 * @package  Net_LDAP
 * @author   Benedikt Hallinger <beni@php.net>
 * @license  http://www.gnu.org/copyleft/lesser.html LGPL
-* @version  CVS: $Id: Filter.php,v 1.26 2007/12/17 06:49:27 beni Exp $
+* @version  CVS: $Id: Filter.php,v 1.27 2008/06/04 06:12:04 beni Exp $
 * @link     http://pear.php.net/package/Net_LDAP/
 */
 class Net_LDAP_Filter extends PEAR
@@ -171,7 +171,7 @@ class Net_LDAP_Filter extends PEAR
             $leaf_filter->_filter = '(' . $attr_name . '<=' . $value . ')';
             break;
         case 'approx':
-            $leaf_filter->_filter = '(' . $attr_name . '=~' . $value . ')';
+            $leaf_filter->_filter = '(' . $attr_name . '~=' . $value . ')';
             break;
         case 'any':
             $leaf_filter->_filter = '(' . $attr_name . '=*)';
@@ -435,4 +435,4 @@ class Net_LDAP_Filter extends PEAR
         }
     }
 }
-?>
\ No newline at end of file
+?>
