@@ -24,9 +24,9 @@ $changes = array(
     ),
     'replace' => array(
         'mail' => array('test1@example.org', 'test2@example.org')
-    )
+    ),
 
-    'delete' = array(
+    'delete' => array(
         'mail' => 'test2@example.org',
         'telephoneNumber' => null     // the null value is important here, sincearray
     )                                 //  mode (indexed, associative) is needed to be homogenous
@@ -57,4 +57,4 @@ if (Net_LDAP::isError($result)) {
     die('Unable to update entry: '.$result->getMessage());
 }
 */
-?>
\ No newline at end of file
+?>
